@@ -28,6 +28,7 @@
 #include "H5Object.h"
 #include "H5FaccProp.h"
 #include "H5FcreatProp.h"
+#include "H5OcreatProp.h"
 #include "H5DcreatProp.h"
 #include "H5DxferProp.h"
 #include "H5CommonFG.h"
@@ -142,7 +143,7 @@ DataType::DataType(const DataType& original) : H5Object()
 //--------------------------------------------------------------------------
 // Function:    DataType overloaded constructor
 ///\brief       Creates a DataType instance using a predefined type
-///\param       pred_type - IN: Predefined type instance
+///\param       pred_type - IN: Predefined datatype
 ///\exception   H5::DataTypeIException
 // Programmer   Binh-Minh Ribler - 2015
 // Description
@@ -156,7 +157,7 @@ DataType::DataType(const PredType& pred_type) : H5Object()
 {
     // call C routine to copy the datatype
     id = H5Tcopy( pred_type.getId() );
-    if( id < 0 )
+    if (id < 0)
 	throw DataTypeIException("DataType constructor", "H5Tcopy failed");
 }
 
@@ -236,8 +237,7 @@ DataType& DataType::operator=( const DataType& rhs )
 {
     if (this != &rhs)
     {
-	id = rhs.id;
-	incRefCount(); // increment number of references to this id
+	setId(rhs.id);
     }
     return(*this);
 }
@@ -758,23 +758,17 @@ void DataType::close()
 //		- Added the use of H5CPP_EXITED to terminate the HDF5 library
 //		  and elimiate previous memory leaks.  See comments in the
 //		  header file "H5PredType.h" for details. - BMR, Mar 30, 2012
+//		- Major re-implementation of the global constants was done
+//		  to avoid relying on the order of the creation and deletion
+//		  of the global constants.  Hence, H5CPP_EXITED was removed.
+//		  See Design Notes in "H5PredType.cpp" for details.
+//		  - BMR, Sep 30, 2015
 //--------------------------------------------------------------------------
 DataType::~DataType()
 {
     try
     {
-	/* If this is the object AtExit, terminate the HDF5 library.  This is
-	   to eliminate memory leaks due to the library being re-initiated
-	   (after the program has ended) and not re-terminated. */
-	if (id == H5CPP_EXITED)
-	{
-	    herr_t ret_value = H5close();
-	    if (ret_value == FAIL)
-		throw DataTypeIException(inMemFunc("~DataType - "), "H5close failed");
-	}
-	// Close the HDF5 datatype
-	else
-	    close();
+	close();
     }
     catch (Exception close_error) {
 	cerr << inMemFunc("~DataType - ") << close_error.getDetailMsg() << endl;
